@@ -205,7 +205,7 @@ class Query(object):
             logging.info(
                  '%.2f\t%s ;\n\t%s'%(
                     1000*(time() - begin_time),
-                    sql.strip()%values
+                    sql.strip()%tuple(values)
                 )
             )
         return cursor
